home | help
UNTITLED()			      LOCAL			      UNTITLED()

NAME
     rux -- used for reading of files in Cyrillic encoding.

SYNOPSIS
     rux [-egtT] [-i incp] [-o outcp] [file ...]

DESCRIPTION
     The  rux is a simple and at the same time powerful utility for texts recod-
     ing from one encoding to another. At present time several the most  popular
     Cyrillic code pages such as koi8-r, cp866, cp1251, iso-8859-5, mac-cyrillic
     and utf-8 are supported. Also rux gives the opportunity to recode box-draw-
     ing  characters,  which exists in some Cyrillic code pages, to replace them
     by their non-graphic analogues ('-', '+', etc.).

     Besides, the rux can detect a code page of the input files automatically.

     Usually rux is used without any options because some values are accepted by
     default. There are -o utf-8, -e, -t, -s 10240.

     However you can use the following options:

     -e    Replace box-drawing characters by their non-graphic	analogues.   Ac-
	   cepted by default.

     -g    Inverse of -e option. (Overrides any previous -e option).

     -t    Attempt  to	detect	a  code page of the input files. Accepted by de-
	   fault.

     -T    Same as -t, but don't actually recode  the  input  files,  just  show
	   their code pages.

     -i    Specify  an input code page. Use -h option to determine the supported
	   code pages list.

     -o    Specify an output code page. Default is `koi8-r'.

     -q    Suspress all warnings.

     -h    Show the short help message with the accepted flags and the supported
	   code pages.

     The expectancy value of the presence of every Cyrillic  characters  in  the
     some  text  were taken from the dump of Russian translation of the `FreeBSD
     Handbook'.

EXAMPLES
     The following is an example of usage of the rux command:

	   $ ls -la *-text
	   -rw-r--r-- 1 ghos users 24 Nov 18 18:03 dos-text
	   -rw-r--r-- 1 ghos users 24 Nov 18 18:03 windows-text

	   $ rux -T *-text
	   dos-text: cp866
	   windows-text: cp1251

     For example, this alias can be set for cp1251 encoding:

	   $ alias cp1251='rux -i cp1251'
	   $ cat windows-text | cp1251
	   ..

     But this shell-script can be created:

	   #!/bin/sh

	   rux $@ | less

     and called as ruless :-):

	   $ ruless cyr-text-file
	   ..
	   $ cat cyr-text-file | ruless
	   ..

SEE ALSO
     Roman Czyborra, The Cyrillic Charset Soup, November 30,  1998,  http://czy-
     borra.com/charsets/cyrillic.html.

HISTORY
     The rux appeared in 2003.

     This manual was written in 2005.

AUTHORS
     Vyacheslav Anikin <anikinsl@gmail.com> -- author, russian manual

BUGS
     Please let me know if you found them. I don't like bugs.

FreeBSD 5.3			November 18, 2005			  RUX(1)

home | help